from urllib.request import (urlopen, Request,)
from json import (loads, dumps,)


class Methods(object,):
	def __init__(self, token,):
		self.token = token

	def createMethod(self, method, json_data,):
		return loads(urlopen(Request(url = 'https://eitaayar.ir/api/{}/{}'.format(self.token, method), headers = {'Accept': 'application/json'}, data = dumps(json_data).encode())).read().decode('utf-8'))


from .methods import (Methods,)


__author__ = 'Shayan Heidari'
__version__ = '1.0.0b'


class Eitaa(object,):
	def __init__(self, token,):
		self.request = Methods(token = token,)

	def getMe(self,):
		result = self.request.createMethod('getMe', {})
		if result.get('ok'):
			return result.get('result')
		else:
			del result
			return None

	def sendMessage(self, chat_id, text, title = None, notification_disable = None, reply_to_message_id = None, date = None, pin = None, viewCountForDelete = None,):
		"""
this is method only for send message in channels or super groups
		"""
		result = self.request.createMethod('sendMessage',
		{
			'chat_id': chat_id,
			'text': text,
			'title': title,
			'notification_disable': notification_disable,
			'reply_to_message_id': reply_to_message_id,
			'date': date,
			'pin': pin,
			'viewCountForDelete': viewCountForDelete,
		},)
		if result.get('ok'):
			return result
		else:
			del result
			return None

	def sendDocument(self,):
		pass

	def sendFile(self, file, caption = None):
		pass


from setuptools import setup, find_packages

setup(
    name = "eitaayar",
    version = "1.0.0",
    author = "Shayan Heidari",
    author_email = "snipe4kill.tg@gmail.com",
    description = "This is an almost official library for managing and building bots in eitaa Messenger...",
    long_description = "Loading...",
    long_description_content_type = "text/markdown",
    url = "https://github.com/snipe4kill/eitaayar/",
    packages = find_packages(),
    classifiers = [
    	"Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "License :: OSI Approved :: MIT License",
    ],
)